==> monodevelop_0.9.orig.tar.gz: monodevelop-0.9/Core/src/MonoDevelop.Projects/MonoDevelop.Projects.Parser/SimpleCodeCompletionDatabase.cs <==
//
// SimpleCodeCompletionDatabase.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using MonoDevelop.Projects.Parser;

namespace MonoDevelop.Projects.Parser
{
	internal class SimpleCodeCompletionDatabase: CodeCompletionDatabase
	{
		string file = "_currentFile";
		
		public SimpleCodeCompletionDatabase (string file, ParserDatabase parserDatabase)
		: base (parserDatabase)
		{
			AddFile (file);
			this.file = file;
		}
		
		public ClassUpdateInformation UpdateFromParseInfo (IParseInformation parserInfo)
		{
			ICompilationUnit cu = (ICompilationUnit)parserInfo.BestCompilationUnit;
			ClassCollection resolved;
			parserDatabase.ResolveTypes (null, cu, cu.Classes, out resolved);
			return UpdateClassInformation (resolved, file);
		}
		
		public override void Read () {}
		public override void Write () {}
	}
}

==> monodevelop_0.14+dfsg.orig.tar.gz: monodevelop-0.14/Core/src/MonoDevelop.Projects/MonoDevelop.Projects.Parser/SimpleCodeCompletionDatabase.cs <==
//
// SimpleCodeCompletionDatabase.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using MonoDevelop.Core;
using MonoDevelop.Projects.Parser;

namespace MonoDevelop.Projects.Parser
{
	internal class SimpleCodeCompletionDatabase: CodeCompletionDatabase
	{
		string file = "_currentFile";
		
		public SimpleCodeCompletionDatabase (string file, ParserDatabase parserDatabase)
		: base (parserDatabase)
		{
			AddFile (file);
			this.file = file;
			
			string requiredRefUri = "Assembly:";
			requiredRefUri += Runtime.SystemAssemblyService.GetAssemblyNameForVersion (typeof(object).Assembly.GetName().ToString(), ClrVersion.Net_1_1);
			AddReference (requiredRefUri);
		}
		
		public ClassUpdateInformation UpdateFromParseInfo (IParseInformation parserInfo)
		{
			ICompilationUnit cu = (ICompilationUnit)parserInfo.BestCompilationUnit;
			UpdateTagComments (cu.TagComments, file);
			ClassCollection resolved;
			parserDatabase.ResolveTypes (null, cu, cu.Classes, out resolved);
			ClassUpdateInformation res = UpdateClassInformation (resolved, file);
			Flush ();
			return res;
		}
		
		public override void Read () {}
		public override void Write () {}
	}
}
